@@ -12,13 +12,13 @@
  * @author Akinobu LEE
  * @date   Thu Feb 17 15:34:39 2005
  *
- * $Revision: 1.9 $
+ * $Revision: 1.13 $
  * 
  */
 /*
- * Copyright (c) 1991-2012 Kawahara Lab., Kyoto University
+ * Copyright (c) 1991-2013 Kawahara Lab., Kyoto University
  * Copyright (c) 2000-2005 Shikano Lab., Nara Institute of Science and Technology
- * Copyright (c) 2005-2012 Julius project team, Nagoya Institute of Technology
+ * Copyright (c) 2005-2013 Julius project team, Nagoya Institute of Technology
  * All rights reserved
  */
 
@@ -88,10 +88,15 @@ confout_lm(FILE *strm)
 #else
   fprintf(strm, "    class N-gram support    : no\n");
 #endif
-#ifdef WORDS_INT
-  fprintf(strm, "    word id unit            : integer (%d bytes)\n", sizeof(WORD_ID));
+#ifdef USE_MBR
+  fprintf(strm, "    MBR weight support      : yes\n");
 #else
-  fprintf(strm, "    word id unit            : short (%d bytes)\n", sizeof(WORD_ID));
+  fprintf(strm, "    MBR weight support      : no\n");
+#endif
+#ifdef WORDS_INT
+  fprintf(strm, "    word id unit            : integer (%lu bytes)\n", sizeof(WORD_ID));
+#else
+  fprintf(strm, "    word id unit            : short (%lu bytes)\n", sizeof(WORD_ID));
 #endif
 }
 
