@@ -20,7 +20,7 @@
  * @author Akinobu LEE
  * @date   Thu Feb 17 18:12:30 2005
  *
- * $Revision: 1.10 $
+ * $Revision: 1.12 $
  * 
  */
 /*
@@ -47,6 +47,8 @@
 #include <sent/mfcc.h>
 #include <sent/htk_param.h>
 
+#define MAXBUFLEN  4096		///< Maximum length of a line in the input
+
 /***********************************************************************/
 /** 
  * Allocate a new delta cycle buffer.
@@ -533,9 +535,9 @@ CMN_load_from_file(CMNWork *c, char *filename)
     int d, dv, len;
 
     jlog("Stat: wav2mfcc-pipe: reading HTK-format cepstral vectors\n");
-    buf = (char *)mymalloc(MAXLINELEN);
+    buf = (char *)mymalloc(MAXBUFLEN);
     mode = 0;
-    while(getl(buf, MAXLINELEN, fp) != NULL) {
+    while(getl(buf, MAXBUFLEN, fp) != NULL) {
       for (p = mystrtok_quote(buf, "<> \t\r\n"); p; p = mystrtok_quote(NULL, "<> \t\r\n")) {
 	switch(mode){
 	case 0:
@@ -547,12 +549,13 @@ CMN_load_from_file(CMNWork *c, char *filename)
 	  break;
 	case 1:
 	  len = atof(p);
-	  if (len != c->veclen) {
+	  if (len != c->veclen && len != c->mfcc_dim) {
 	    jlog("Error: wav2mfcc-pipe: cepstral dimension mismatch\n");
-	    jlog("Error: wav2mfcc-pipe: process = %d, file = %d\n", c->veclen, len);
+	    jlog("Error: wav2mfcc-pipe: process = %d (%d), file = %d\n", c->veclen, c->mfcc_dim, len);
 	    free(buf); fclose_readfile(fp);
 	    return(FALSE);
 	  }
+	  for (d = 0; d < c->veclen; d++) c->cmean_init[d] = 0.0;
 	  d = 0;
 	  mode = 2;
 	  break;
@@ -662,17 +665,17 @@ CMN_save_to_file(CMNWork *c, char *filename)
   }
 
   fprintf(fp, "<CEPSNORM> <>\n");
+  /* unlike HTK, full mean will be written for variance estimation */
   fprintf(fp, "<MEAN> %d\n", c->veclen);
   for(d=0;d<c->veclen;d++) {
-    fprintf(fp, " %e", c->cmean_init[d]);
+    fprintf(fp, " %e\n", c->cmean_init[d]);
   }
   if (c->var) {
-    fprintf(fp, "\n<VARIANCE> %d\n", c->veclen);
+    fprintf(fp, "<VARIANCE> %d\n", c->veclen);
     for(d=0;d<c->veclen;d++) {
-      fprintf(fp, " %e", c->cvar_init[d]);
+      fprintf(fp, " %e\n", c->cvar_init[d]);
     }
   }
-  fprintf(fp, "\n");
 
   fclose_writefile(fp);
 
